@@ -28,7 +28,7 @@
 #include "account.h"
 #include "private/queuehelper_p.h"
 
-#include <QtNetwork/QNetworkRequest>
+#include <QNetworkRequest>
 
 using namespace KGAPI2;
 
@@ -59,7 +59,7 @@ QNetworkRequest ContactsGroupDeleteJob::Private::createRequest(const QUrl& url)
     QStringList headers;
     auto rawHeaderList = request.rawHeaderList();
     headers.reserve(rawHeaderList.size());
-    Q_FOREACH(const QByteArray &str, rawHeaderList) {
+    for (const QByteArray &str : qAsConst(rawHeaderList)) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
@@ -73,7 +73,7 @@ ContactsGroupDeleteJob::ContactsGroupDeleteJob(const ContactsGroupsList& groups,
     d(new Private(this))
 {
     d->groupsIds.reserve(groups.size());
-    Q_FOREACH(const ContactsGroupPtr &group, groups) {
+    for(const ContactsGroupPtr &group : groups) {
         d->groupsIds << group->id();
     }
 }
